@@ -73,415 +73,416 @@
 #' #the first step estimation. 
 #'
 TVAR <- function(data, lag, include = c( "const", "trend","none", "both"), model=c("TAR", "MTAR"), commonInter=FALSE, nthresh=1,thDelay=1, mTh=1,thVar, trim=0.1,ngrid, gamma=NULL,  around, plot=FALSE, dummyToBothRegimes=TRUE, trace=TRUE, trick="for", max.iter=2){
-y <- as.matrix(data)
-Torigin <- nrow(y) 	#Size of original sample
-T <- nrow(y) 		#Size of start sample
-p <- lag
-t <- T-p 		#Size of end sample
-k <- ncol(y) 		#Number of variables
-t<-T-p			#Size of end sample
-
-
-if(is.null(colnames(data)))
-	colnames(data)<-paste("Var", c(1:k), sep="")
-if(max(thDelay)>p)
-	stop("Max of thDelay should be smaller or equal to the number of lags")
-if(dummyToBothRegimes==FALSE&nthresh!= 1) 
-	warning("The 'dummyToBothRegimes' argument is only relevant for one threshold models")
-model<-match.arg(model)
-include<-match.arg(include)
-
-Y <- y[(p+1):T,] #
-Z <- embed(y, p+1)[, -seq_len(k)]	#Lags matrix
-
-if(include=="const")
-	Z<-cbind(1, Z)
-else if(include=="trend")
-	Z<-cbind(seq_len(t), Z)
-else if(include=="both")
-	Z<-cbind(rep(1,t),seq_len(t), Z)
-if(commonInter & include!="const")
-	stop("commonInter argument only avalaible with include = const")
-npar <- ncol(Z)			#Number of parameters
-
-
-########################
-### Threshold variable
-########################
-
-###External threshold variable
-if (!missing(thVar)) {		
-        if (length(thVar) > Torigin) {
-		z <- thVar[seq_len(Torigin)]
-		warning("The external threshold variable is not of same length as the original variable")
-        }
-        else
-		z <- thVar
-	z<-embed(z,p+1)[,seq_len(max(thDelay))+1]		#if thDelay=2, ncol(z)=2
-combin<-NULL
-} ###Combination (or single value indicating position) of contemporaneous variables
-else {
-	if (!length(mTh)%in%c(1,k))
-		stop("length of 'mTh' should be equal to the number of variables, or just one")
-	if(length(mTh)==1) {
-		if(mTh>k)
-			stop("Unable to select the ",mTh, "variable for the threshold. Please see again mTh ")
-		combin <- matrix(0,ncol=1, nrow=k)
-		combin[mTh,]<-1
-	}
-	else 
-		combin<-matrix(mTh,ncol=1, nrow=k)
-	zcombin <- y %*% combin
-	if(model=="MTAR"){
-		if(max(thDelay)<p)
-			z<-embed(diff(zcombin),p)[,seq_len(max(thDelay))+1]
-		else if(max(thDelay)==p){
-			z<-embed(diff(zcombin),p+1)[,seq_len(max(thDelay))+1]
-			z<-rbind(0,as.matrix(z))}
-	}
-	else
-		z <- embed(zcombin,p+1)[,seq_len(max(thDelay))+1]		#if thDelay=2, ncol(z)=2
-}
-
-trans<-as.matrix(z)
-
-###############################
-###Grid for transition variable
-###############################
-
-allgammas <- sort(unique(trans[,1]))
-nga <- length(allgammas)
-ninter <- round(trim*nga)
-gammas <- allgammas[(trim*nga):((1-trim)*nga)]
-
-
-
-if(!missing(ngrid)){
-	gammas <- allgammas[seq(from=ceiling(trim*nga), to=floor((1-trim)*nga), length.out=ngrid)]
-}
-if(!missing(gamma)){
-	gammas<-gamma
-	plot<-FALSE
-}
-
-Y_t<-t(Y)					#dim k x t
-
-if(!missing(around)){
-	if(missing(ngrid)) ngrid<-20
-	if(length(around)==1)
-		gammas <- aroundGrid(around, allgammas,ngrid,trim, trace=trace)
-	if(length(around)==2) {
-		gammas <- aroundGrid(around[1], allgammas,ngrid,trim, trace=trace)
-		gammas2 <- aroundGrid(around[2], allgammas,ngrid,trim, trace=trace)
-	}
-}
-
-######################
-###One threshold functions					
-######################
-
-#Model with dummy applied to only one regime
-loop1_onedummy <- function(gam1, thDelay){
-	##Threshold dummies
-	dummyDown <- ifelse(trans[,thDelay]<=gam1, 1,0) * Z
-	ndown<-mean(dummyDown)
-	regimeDown<-dummyDown*Z
-	##SSR
-	if(min(ndown, 1-ndown)>=trim){
-		Z1 <- cbind(regimeDown, Z)		# dim t x k(p+1) 
-		res <- crossprod(c(lm.fit(x=Z1, y=Y)$resid))
-	}	else {
-		res<-NA
-	}
-	return(res)
-} #end of the function
-
-
-#Model with dummy applied to both regimes
-loop1_twodummy <- function(gam1, thDelay){
-	##Threshold dummies
-	d1<-ifelse(trans[,thDelay]<=gam1, 1,0)
-	ndown<-mean(d1)
-	##SSR
-	if(min(ndown, 1-ndown)>=trim){
-	  Z1 <- cbind(d1 * Z, (1-d1)*Z)    # dim k(p+1) x t
-	  res <- crossprod(c(lm.fit(x=Z1, y=Y)$resid))
-	}	else{
-		res<-NA
-	}
-	return(res)
-} #end of the function
-
-#Model with dummy applied to both regimes and a common intercept
-loop1_twodummy_oneIntercept <- function(gam1, thDelay){
-	##Threshold dummies
-	d1<-ifelse(trans[,thDelay]<=gam1, 1,0)
-	ndown<-mean(d1)
-	if(min(ndown, 1-ndown)>=trim){
-		Z1 <- cbind(1,d1 * Z[,-1], (1-d1)*Z[,-1])		# dim k(p+1) x t
-		res <- crossprod(c(lm.fit(x=Z1, y=Y)$resid)) 
-	} else {
-		res<-NA
-	}
-	return(res)
-} #end of the function
-
-
-#######################
-###Two thresholds functions
-#######################
-
-loop2 <- function(gam1, gam2,thDelay){
-	##Threshold dummies
-	dummydown <- ifelse(trans[,thDelay]<=gam1, 1, 0)
-	regimedown <- dummydown*Z
-	ndown <- mean(dummydown)
-	dummyup <- ifelse(trans[,thDelay]>gam2, 1, 0)
-	regimeup <- dummyup*Z
-	nup <- mean(dummyup)
-	##SSR from TVAR(3)
-	#print(c(ndown,1-nup-ndown,nup))
-	if(min(nup, ndown, 1-nup-ndown)>trim){
-		Z2 <- cbind(regimedown, (1-dummydown-dummyup)*Z, regimeup)		# dim k(p+1) x t
-		res <- crossprod(c(lm.fit(x=Z2, y=Y)$resid)) 
-	}
-	else
-		res <- NA
-	return(res)
-}
-
-loop2_oneIntercept <- function(gam1, gam2,thDelay){
-	##Threshold dummies
-	dummydown <- ifelse(trans[,thDelay]<=gam1, 1, 0)
-	regimedown <- dummydown*Z[,-1]
-	ndown <- mean(dummydown)
-	dummyup <- ifelse(trans[,thDelay]>gam2, 1, 0)
-	regimeup <- dummyup*Z[,-1]
-	nup <- mean(dummyup)
-	##SSR from TVAR(3)
-	#print(c(ndown,1-nup-ndown,nup))
-	if(min(nup, ndown, 1-nup-ndown)>trim){
-		Z2 <- cbind(1,regimedown, (1-dummydown-dummyup)*Z, regimeup)		# dim k(p+1) x t	
-		res <- crossprod(c(lm.fit(x=Z2, y=Y)$resid)) 
-	}
-	else
-		res <- NA
-	return(res)
-}
-############################
-###Search for one threshold
-############################
-if(!missing(around))
-	gammas <- aroundGrid(around,allgammas,ngrid,trim, trace=trace)
-if(dummyToBothRegimes){
-	if(commonInter)
-		func<-loop1_twodummy_oneIntercept
-	else
-		func <-loop1_twodummy}
-else	
-	func <- loop1_onedummy
-
-
-bestone <- onesearch(thDelay,gammas, fun=func, trace=trace, gamma=gamma, plot=plot)
-bestThresh <- bestone$bestThresh
-bestDelay <- bestone$bestDelay
-allThSSR<-bestone$allres
-
-
-############################
-###Search for two threshold
-############################
-
-
-if(nthresh==2){
-  ###Conditionnal step
-  if(commonInter)
-	func2<-loop2_oneIntercept
-  else
-	func2<-loop2
-# secondBestThresh<-condiStep(allgammas, threshRef=bestThresh, delayRef=bestDelay,ninter=ninter, fun=func2)$newThresh
-# step2FirstBest<-condiStep(allgammas, threshRef=secondBestThresh, delayRef=bestDelay,ninter=ninter, fun=func2)
-
-last<-condiStep(allgammas, threshRef=bestThresh, delayRef=bestDelay, fun=func2, trim=trim, trace=trace)
-i<-1
-while(i<max.iter){
-	b<-condiStep(allgammas, threshRef=last$newThresh, delayRef=bestDelay, fun=func2, trim=trim, trace=trace)
-	if(b$SSR<last$SSR){	#minimum still not reached
-		i<-i+1
-		last<-b}
-	else{			#minimum reached
-		i<-max.iter
-		last<-b}
-}
-
-bests<-c(last$threshRef, last$newThresh)
-
-###Alternative step: grid around the points from first step
-smallThresh <- min(bests)		#bestThresh,secondBestThresh)
-gammasDown <- aroundGrid(around=smallThresh,allgammas,ngrid=30, trim=trim, trace=trace)
-
-bigThresh <- max(bests)			#bestThresh,secondBestThresh)
-gammasUp <- aroundGrid(around=bigThresh,allgammas,ngrid=30, trim=trim, trace=trace)
-
-bestThresh<-grid(gammasUp, gammasDown, fun=func2, method=trick, thDelay=bestDelay, trace=trace)
-
-}#end if nthresh=2
-
-###Search both thresholds with d given
-
-if(nthresh==3){
-bestDelay <- thDelay
-if(missing(gamma)==FALSE){
-	gammas <- gamma[1]
-	gammas2 <- gamma[2]
-	ninter<- 2
-	cat("To be corrected!!")
-}
-if(missing(around)==FALSE){
-	if(length(around)!=2)
-		stop("Please give two thresholds possible values to search around")
-	gammas <- aroundGrid(min(around), allgammas, ngrid=ngrid, trim=trim, trace=trace)
-	gammas2 <- aroundGrid(max(around), allgammas, ngrid=ngrid, trim=trim, trace=trace)
-}
-else {
-	gammas2 <- gammas
-	if(length (gammas) * length(gammas2)/2>10000)
-		cat("The function will compute about", length(gammas)*length(gammas2)/2, "operations. Take a coffee and come back\n")
-}
-if(length(thDelay)>1) stop("length of thDelay should not be bigger than 1. The whole search is made only upon the thresholds with given delay")
-
-store3 <- matrix(NA,ncol=length(gammas2), nrow=length(gammas))
-
-###Loop
-for(i in seq_len(length(gammas))){
-	gam1 <- gammas[i]
-	for (j in seq_len(length(gammas))){
-		gam2 <- gammas2[j]
-		store3[i,j] <- loop2(gam1, gam2, thDelay=bestDelay)
-	}
-}
-
-position <- which(store3==min(store3, na.rm=TRUE), arr.ind=TRUE)
-r <- position[1]
-c <- position[2]
-
-gamma1 <- gammas[r]
-gamma2 <- gammas2[c]
-bestThresh <- c(gamma1, gamma2)
-
-}#end n
-
-#############
-###Best Model
-#############
-if(commonInter)
-	val<- 1
-else
-	val<- -(seq_len(ncol(Z)))
-
-if(nthresh==1){
-	dummydown <- ifelse(trans[,bestDelay]<=bestThresh, 1, 0)
-	ndown <- mean(dummydown)
-	regimeDown <- dummydown*Z[,-val]
-	dummyup<-1-dummydown
-	if(dummyToBothRegimes) 
-		regimeUp<-dummyup*Z[,-val]
-	else regimeUp<-Z
-	if(commonInter)
-		Zbest<-cbind(1,regimeDown,regimeUp)
-	else
-		Zbest <- cbind(regimeDown,regimeUp)		# dim k(p+1) x t
-}
-
-if(nthresh==2|nthresh==3){
-	dummydown <- ifelse(trans[,bestDelay]<=bestThresh[1], 1,0)
-	ndown <- mean(dummydown)
-	regimedown <- dummydown*Z[,-val]
-	dummyup <- ifelse(trans[,bestDelay]>bestThresh[2], 1,0)
-	nup <- mean(dummyup)
-	regimeup <- dummyup*Z[,-val]
-	dummymid<-1-dummydown-dummyup
-	if(commonInter)
-		Zbest <- cbind(1,regimedown,dummymid*Z[,-1], regimeup)	# dim k(p+1) x t
-	else
-		Zbest <- cbind(regimedown,dummymid*Z, regimeup)	# dim k(p+1) x t
-}
-
-Zbest_t <- t(Zbest)
-reg<-if(nthresh==1) dummydown+2*dummyup else dummydown+2*dummymid+3*dummyup
-regime <- c(rep(NA, T-t), reg)
-
-
-final <- lm.fit(x=Zbest, y=Y)
-
-Bbest <- t(final$coef)
-fitted <- final$fitted
-resbest <- final$residuals
-
-SSRbest <- as.numeric(crossprod(c(resbest)))
-nparbest<-nrow(Bbest)*ncol(Bbest)
-
-Sigmabest<-matrix(1/t*crossprod(resbest),ncol=k,dimnames=list(colnames(data), colnames(data)))
-SigmabestOls<-Sigmabest*(t/(t-ncol(Bbest)))
-
-###naming and dividing B
-rownames(Bbest) <- paste("Equation", colnames(data))
-LagNames<-c(paste(rep(colnames(data),p), -rep(seq_len(p), each=k)))
-
-Bnames<-c(switch(include, const="Intercept", trend="Trend", both=c("Intercept","Trend"), none=NULL),LagNames)
-Blist<-nameB(mat=Bbest, commonInter=commonInter, Bnames=Bnames, nthresh=nthresh, npar=npar)
-BnamesVec<-if(class(Blist)=="list") c(sapply(Blist, colnames)) else colnames(Blist)
-colnames(Bbest)<-BnamesVec
-
-##number of obs in each regime
-if(nthresh==1)
-	nobs <- c(ndown=ndown, nup=1-ndown)
-else if (nthresh==2)
-	nobs <- c(ndown=ndown, nmiddle=1-nup-ndown,nup=nup)
-
-###Y and regressors matrix
-tZbest<-Zbest
-naX<-rbind(matrix(NA, ncol=ncol(tZbest), nrow=p), tZbest)
-YnaX<-cbind(data, naX)
-BlistMod<-nameB(mat=Bbest, commonInter=commonInter, Bnames=Bnames, nthresh=nthresh, npar=npar,sameName=FALSE )
-BnamesVecMod<-if(class(BlistMod)=="list") c(sapply(BlistMod, colnames)) else colnames(BlistMod)
-colnames(YnaX)<-c(colnames(data),BnamesVecMod)
-
-###elements to return
-specific<-list()
-specific$allgammas<-allgammas
-specific$gammas<-gammas
-specific$thDelay<-bestDelay
-specific$Thresh<-bestThresh
-specific$nthresh<-nthresh
-specific$transCombin<-combin
-specific$regime<-regime
-specific$nreg<-nthresh+1
-specific$nrowB<-npar
-specific$nobs<-nobs
-specific$oneMatrix<-commonInter
-specific$threshEstim<-ifelse(is.null(gamma), TRUE, FALSE)
-specific$allThSSR<-allThSSR#SSR values for all the th computed
-specific$Bnames<-Bnames
-specific$timeAttributes <- attributes(data[,1])
-
-z<-list(coefficients=Blist, coeffmat=Bbest, residuals=resbest, model=YnaX, 
-        nobs_regimes=nobs, k=k, t=t, T=T,nparB=nparbest, df.residual=t-ncol(Bbest),
-        fitted.values=fitted, lag=lag, include=include,model.specific=specific, 
-        usedThVar=trans[,bestDelay], trim=trim)
-class(z)<-c("TVAR","nlVar")
-attr(z, "levelTransVar")<-model
-attr(z, "transVar")<-if(!missing(thVar)) "external" else "internal"
-attr(z, "varsLevel")<-"level"
-
-if(plot){
-  layout(matrix(1:ifelse(z$model.specific$threshEstim,3,2), ncol=1))
-  plot1(bestThresh, nthresh,usedThVar=z$usedThVar)
-  plot2(bestThresh, nthresh,usedThVar=z$usedThVar, trim=z$trim)
-  if(z$model.specific$threshEstim)
-    plot3(bestThresh, nthresh,allTh=z$model.specific$allThSSR)
-}
-return(z)
+  
+  ## arg matching
+  model<-match.arg(model)
+  include<-match.arg(include)
+  
+  y <- as.matrix(data)
+  Torigin <- nrow(y) 	#Size of original sample
+  T <- nrow(y) 		#Size of start sample
+  p <- lag
+  t <- T-p 		#Size of end sample
+  k <- ncol(y) 		#Number of variables
+  t<-T-p			#Size of end sample
+  
+  
+  if(is.null(colnames(data)))
+    colnames(data)<-paste("Var", c(1:k), sep="")
+  if(max(thDelay)>p)
+    stop("Max of thDelay should be smaller or equal to the number of lags")
+  if(dummyToBothRegimes==FALSE&nthresh!= 1) 
+    warning("The 'dummyToBothRegimes' argument is only relevant for one threshold models")
+  
+  Y <- y[(p+1):T,] #
+  Z <- embed(y, p+1)[, -seq_len(k)]	#Lags matrix
+  
+  if(include=="const")
+    Z<-cbind(1, Z)
+  else if(include=="trend")
+    Z<-cbind(seq_len(t), Z)
+  else if(include=="both")
+    Z<-cbind(rep(1,t),seq_len(t), Z)
+  if(commonInter & include!="const")
+    stop("commonInter argument only avalaible with include = const")
+  npar <- ncol(Z)			#Number of parameters
+  
+  
+  ########################
+  ### Threshold variable
+  ########################
+  
+  ###External threshold variable
+  if (!missing(thVar)) {		
+    if (length(thVar) > Torigin) {
+      z <- thVar[seq_len(Torigin)]
+      warning("The external threshold variable is not of same length as the original variable")
+    } else {
+      z <- thVar
+    }
+    z<-embed(z,p+1)[,seq_len(max(thDelay))+1]		#if thDelay=2, ncol(z)=2
+    combin<-NULL
+  } ###Combination (or single value indicating position) of contemporaneous variables
+  else {
+    if (!length(mTh)%in%c(1,k))
+      stop("length of 'mTh' should be equal to the number of variables, or just one")
+    if(length(mTh)==1) {
+      if(mTh>k)
+        stop("Unable to select the ",mTh, "variable for the threshold. Please see again mTh ")
+      combin <- matrix(0,ncol=1, nrow=k)
+      combin[mTh,]<-1
+    } else { 
+      combin<-matrix(mTh,ncol=1, nrow=k)
+    }
+    zcombin <- y %*% combin
+    if(model=="MTAR"){
+      if(max(thDelay)<p) {
+        z<-embed(diff(zcombin),p)[,seq_len(max(thDelay))+1]
+      } else if(max(thDelay)==p){ {
+        z<-embed(diff(zcombin),p+1)[,seq_len(max(thDelay))+1]
+      }
+        z<-rbind(0,as.matrix(z))}
+    } else {
+      z <- embed(zcombin,p+1)[,seq_len(max(thDelay))+1]		#if thDelay=2, ncol(z)=2
+    }
+  }
+  
+  trans<-as.matrix(z)
+  
+  ###############################
+  ###Grid for transition variable
+  ###############################
+  
+  allgammas <- sort(unique(trans[,1]))
+  nga <- length(allgammas)
+  ninter <- round(trim*nga)
+  gammas <- allgammas[(trim*nga):((1-trim)*nga)]
+  
+  
+  
+  if(!missing(ngrid)){
+    gammas <- allgammas[seq(from=ceiling(trim*nga), to=floor((1-trim)*nga), length.out=ngrid)]
+  }
+  if(!missing(gamma)){
+    gammas<-gamma
+    plot<-FALSE
+  }
+  
+  Y_t<-t(Y)					#dim k x t
+  
+  if(!missing(around)){
+    if(missing(ngrid)) ngrid<-20
+    if(length(around)==1)
+      gammas <- aroundGrid(around, allgammas,ngrid,trim, trace=trace)
+    if(length(around)==2) {
+      gammas <- aroundGrid(around[1], allgammas,ngrid,trim, trace=trace)
+      gammas2 <- aroundGrid(around[2], allgammas,ngrid,trim, trace=trace)
+    }
+  }
+  
+  ######################
+  ###One threshold functions					
+  ######################
+  
+  #Model with dummy applied to only one regime
+  loop1_onedummy <- function(gam1, thDelay){
+    ##Threshold dummies
+    dummyDown <- ifelse(trans[,thDelay]<=gam1, 1,0) * Z
+    ndown<-mean(dummyDown)
+    regimeDown<-dummyDown*Z
+    ##SSR
+    if(min(ndown, 1-ndown)>=trim){
+      Z1 <- cbind(regimeDown, Z)		# dim t x k(p+1) 
+      res <- crossprod(c(lm.fit(x=Z1, y=Y)$resid))
+    }	else {
+      res<-NA
+    }
+    return(res)
+  } #end of the function
+  
+  
+  #Model with dummy applied to both regimes
+  loop1_twodummy <- function(gam1, thDelay){
+    ##Threshold dummies
+    d1<-ifelse(trans[,thDelay]<=gam1, 1,0)
+    ndown<-mean(d1)
+    ##SSR
+    if(min(ndown, 1-ndown)>=trim){
+      Z1 <- cbind(d1 * Z, (1-d1)*Z)    # dim k(p+1) x t
+      res <- crossprod(c(lm.fit(x=Z1, y=Y)$resid))
+    }	else{
+      res<-NA
+    }
+    return(res)
+  } #end of the function
+  
+  #Model with dummy applied to both regimes and a common intercept
+  loop1_twodummy_oneIntercept <- function(gam1, thDelay){
+    ##Threshold dummies
+    d1<-ifelse(trans[,thDelay]<=gam1, 1,0)
+    ndown<-mean(d1)
+    if(min(ndown, 1-ndown)>=trim){
+      Z1 <- cbind(1,d1 * Z[,-1], (1-d1)*Z[,-1])		# dim k(p+1) x t
+      res <- crossprod(c(lm.fit(x=Z1, y=Y)$resid)) 
+    } else {
+      res<-NA
+    }
+    return(res)
+  } #end of the function
+  
+  
+  #######################
+  ###Two thresholds functions
+  #######################
+  
+  loop2 <- function(gam1, gam2,thDelay){
+    ##Threshold dummies
+    dummydown <- ifelse(trans[,thDelay]<=gam1, 1, 0)
+    regimedown <- dummydown*Z
+    ndown <- mean(dummydown)
+    dummyup <- ifelse(trans[,thDelay]>gam2, 1, 0)
+    regimeup <- dummyup*Z
+    nup <- mean(dummyup)
+    ##SSR from TVAR(3)
+    #print(c(ndown,1-nup-ndown,nup))
+    if(min(nup, ndown, 1-nup-ndown)>trim){
+      Z2 <- cbind(regimedown, (1-dummydown-dummyup)*Z, regimeup)		# dim k(p+1) x t
+      res <- crossprod(c(lm.fit(x=Z2, y=Y)$resid)) 
+    }
+    else
+      res <- NA
+    return(res)
+  }
+  
+  loop2_oneIntercept <- function(gam1, gam2,thDelay){
+    ##Threshold dummies
+    dummydown <- ifelse(trans[,thDelay]<=gam1, 1, 0)
+    regimedown <- dummydown*Z[,-1]
+    ndown <- mean(dummydown)
+    dummyup <- ifelse(trans[,thDelay]>gam2, 1, 0)
+    regimeup <- dummyup*Z[,-1]
+    nup <- mean(dummyup)
+    ##SSR from TVAR(3)
+    #print(c(ndown,1-nup-ndown,nup))
+    if(min(nup, ndown, 1-nup-ndown)>trim){
+      Z2 <- cbind(1,regimedown, (1-dummydown-dummyup)*Z, regimeup)		# dim k(p+1) x t	
+      res <- crossprod(c(lm.fit(x=Z2, y=Y)$resid)) 
+    }
+    else
+      res <- NA
+    return(res)
+  }
+  ############################
+  ###Search for one threshold
+  ############################
+  if(!missing(around))
+    gammas <- aroundGrid(around,allgammas,ngrid,trim, trace=trace)
+  if(dummyToBothRegimes){
+    if(commonInter)
+      func<-loop1_twodummy_oneIntercept
+    else
+      func <-loop1_twodummy
+  } else {	
+    func <- loop1_onedummy
+  }
+  
+  bestone <- onesearch(thDelay,gammas, fun=func, trace=trace, gamma=gamma, plot=plot)
+  bestThresh <- bestone$bestThresh
+  bestDelay <- bestone$bestDelay
+  allThSSR<-bestone$allres
+  
+  
+  ############################
+  ###Search for two threshold
+  ############################
+  
+  
+  if(nthresh==2){
+    ###Conditionnal step
+    if(commonInter)
+      func2<-loop2_oneIntercept
+    else
+      func2<-loop2
+    # secondBestThresh<-condiStep(allgammas, threshRef=bestThresh, delayRef=bestDelay,ninter=ninter, fun=func2)$newThresh
+    # step2FirstBest<-condiStep(allgammas, threshRef=secondBestThresh, delayRef=bestDelay,ninter=ninter, fun=func2)
+    
+    last<-condiStep(allgammas, threshRef=bestThresh, delayRef=bestDelay, fun=func2, trim=trim, trace=trace)
+    i<-1
+    while(i<max.iter){
+      b<-condiStep(allgammas, threshRef=last$newThresh, delayRef=bestDelay, fun=func2, trim=trim, trace=trace)
+      if(b$SSR<last$SSR){	#minimum still not reached
+        i<-i+1
+        last<-b}
+      else{			#minimum reached
+        i<-max.iter
+        last<-b}
+    }
+    
+    bests<-c(last$threshRef, last$newThresh)
+    
+    ###Alternative step: grid around the points from first step
+    smallThresh <- min(bests)		#bestThresh,secondBestThresh)
+    gammasDown <- aroundGrid(around=smallThresh,allgammas,ngrid=30, trim=trim, trace=trace)
+    
+    bigThresh <- max(bests)			#bestThresh,secondBestThresh)
+    gammasUp <- aroundGrid(around=bigThresh,allgammas,ngrid=30, trim=trim, trace=trace)
+    
+    bestThresh<-grid(gammasUp, gammasDown, fun=func2, method=trick, thDelay=bestDelay, trace=trace)
+    
+  }#end if nthresh=2
+  
+  ###Search both thresholds with d given
+  
+  if(nthresh==3){
+    bestDelay <- thDelay
+    if(missing(gamma)==FALSE){
+      gammas <- gamma[1]
+      gammas2 <- gamma[2]
+      ninter<- 2
+      cat("To be corrected!!")
+    }
+    if(missing(around)==FALSE){
+      if(length(around)!=2)
+        stop("Please give two thresholds possible values to search around")
+      gammas <- aroundGrid(min(around), allgammas, ngrid=ngrid, trim=trim, trace=trace)
+      gammas2 <- aroundGrid(max(around), allgammas, ngrid=ngrid, trim=trim, trace=trace)
+    }
+    else {
+      gammas2 <- gammas
+      if(length (gammas) * length(gammas2)/2>10000)
+        cat("The function will compute about", length(gammas)*length(gammas2)/2, "operations. Take a coffee and come back\n")
+    }
+    if(length(thDelay)>1) stop("length of thDelay should not be bigger than 1. The whole search is made only upon the thresholds with given delay")
+    
+    store3 <- matrix(NA,ncol=length(gammas2), nrow=length(gammas))
+    
+    ###Loop
+    for(i in seq_len(length(gammas))){
+      gam1 <- gammas[i]
+      for (j in seq_len(length(gammas))){
+        gam2 <- gammas2[j]
+        store3[i,j] <- loop2(gam1, gam2, thDelay=bestDelay)
+      }
+    }
+    
+    position <- which(store3==min(store3, na.rm=TRUE), arr.ind=TRUE)
+    r <- position[1]
+    c <- position[2]
+    
+    gamma1 <- gammas[r]
+    gamma2 <- gammas2[c]
+    bestThresh <- c(gamma1, gamma2)
+    
+  }#end n
+  
+  #############
+  ###Best Model
+  #############
+  val <- if(commonInter) 1 else -(seq_len(ncol(Z)))
+  
+  if(nthresh==1){
+    dummydown <- ifelse(trans[,bestDelay]<=bestThresh, 1, 0)
+    ndown <- mean(dummydown)
+    regimeDown <- dummydown*Z[,-val]
+    dummyup<-1-dummydown
+    if(dummyToBothRegimes) 
+      regimeUp<-dummyup*Z[,-val]
+    else regimeUp<-Z
+    if(commonInter)
+      Zbest<-cbind(1,regimeDown,regimeUp)
+    else
+      Zbest <- cbind(regimeDown,regimeUp)		# dim k(p+1) x t
+  }
+  
+  if(nthresh==2|nthresh==3){
+    dummydown <- ifelse(trans[,bestDelay]<=bestThresh[1], 1,0)
+    ndown <- mean(dummydown)
+    regimedown <- dummydown*Z[,-val]
+    dummyup <- ifelse(trans[,bestDelay]>bestThresh[2], 1,0)
+    nup <- mean(dummyup)
+    regimeup <- dummyup*Z[,-val]
+    dummymid<-1-dummydown-dummyup
+    if(commonInter)
+      Zbest <- cbind(1,regimedown,dummymid*Z[,-1], regimeup)	# dim k(p+1) x t
+    else
+      Zbest <- cbind(regimedown,dummymid*Z, regimeup)	# dim k(p+1) x t
+  }
+  
+  Zbest_t <- t(Zbest)
+  reg<-if(nthresh==1) dummydown+2*dummyup else dummydown+2*dummymid+3*dummyup
+  regime <- c(rep(NA, T-t), reg)
+  
+  
+  final <- lm.fit(x=Zbest, y=Y)
+  
+  Bbest <- t(final$coef)
+  fitted <- final$fitted
+  resbest <- final$residuals
+  
+  SSRbest <- as.numeric(crossprod(c(resbest)))
+  nparbest<-nrow(Bbest)*ncol(Bbest)
+  
+  Sigmabest<-matrix(1/t*crossprod(resbest),ncol=k,dimnames=list(colnames(data), colnames(data)))
+  SigmabestOls<-Sigmabest*(t/(t-ncol(Bbest)))
+  
+  ### naming and splitting B
+  rownames(Bbest) <- paste("Equation", colnames(data))
+  LagNames<-c(paste(rep(colnames(data),p), -rep(seq_len(p), each=k)))
+  
+  Bnames<-c(switch(include, const="Intercept", trend="Trend", both=c("Intercept","Trend"), none=NULL), LagNames)
+  Blist<-nameB(mat=Bbest, commonInter=commonInter, Bnames=Bnames, nthresh=nthresh, npar=npar)
+  BnamesVec<-if(class(Blist)=="list") c(sapply(Blist, colnames)) else colnames(Blist)
+  colnames(Bbest)<-BnamesVec
+  
+  ##number of obs in each regime
+  if(nthresh==1)
+    nobs <- c(ndown=ndown, nup=1-ndown)
+  else if (nthresh==2)
+    nobs <- c(ndown=ndown, nmiddle=1-nup-ndown,nup=nup)
+  
+  ###Y and regressors matrix
+  tZbest<-Zbest
+  naX<-rbind(matrix(NA, ncol=ncol(tZbest), nrow=p), tZbest)
+  YnaX<-cbind(data, naX)
+  BlistMod<-nameB(mat=Bbest, commonInter=commonInter, Bnames=Bnames, nthresh=nthresh, npar=npar,sameName=FALSE )
+  BnamesVecMod<-if(class(BlistMod)=="list") c(sapply(BlistMod, colnames)) else colnames(BlistMod)
+  colnames(YnaX)<-c(colnames(data),BnamesVecMod)
+  
+  ###elements to return
+  specific<-list()
+  specific$allgammas<-allgammas
+  specific$gammas<-gammas
+  specific$thDelay<-bestDelay
+  specific$Thresh<-bestThresh
+  specific$nthresh<-nthresh
+  specific$transCombin<-combin
+  specific$regime<-regime
+  specific$nreg<-nthresh+1
+  specific$nrowB<-npar
+  specific$nobs<-nobs
+  specific$oneMatrix<-commonInter
+  specific$threshEstim<-ifelse(is.null(gamma), TRUE, FALSE)
+  specific$allThSSR<-allThSSR#SSR values for all the th computed
+  specific$Bnames<-Bnames
+  specific$timeAttributes <- attributes(data[,1])
+  
+  z<-list(coefficients=Blist, coeffmat=Bbest, residuals=resbest, model=YnaX, 
+          nobs_regimes=nobs, k=k, t=t, T=T,nparB=nparbest, df.residual=t-ncol(Bbest),
+          fitted.values=fitted, lag=lag, include=include,model.specific=specific, 
+          usedThVar=trans[,bestDelay], trim=trim)
+  class(z)<-c("TVAR","nlVar")
+  attr(z, "levelTransVar") <- model
+  attr(z, "transVar") <- if(!missing(thVar)) "external" else "internal"
+  attr(z, "varsLevel") <- "level"
+  
+  if(plot){
+    layout(matrix(1:ifelse(z$model.specific$threshEstim,3,2), ncol=1))
+    plot1(bestThresh, nthresh,usedThVar=z$usedThVar)
+    plot2(bestThresh, nthresh,usedThVar=z$usedThVar, trim=z$trim)
+    if(z$model.specific$threshEstim)
+      plot3(bestThresh, nthresh,allTh=z$model.specific$allThSSR)
+  }
+  return(z)
 }	#end of the whole function
 
 
@@ -693,7 +694,7 @@ toLatex.TVAR<-function(object,..., digits=4, parenthese=c("StDev","Pvalue")){
 }
 
 
-nameB<-function(mat,commonInter, Bnames, nthresh, npar, model=c("TVAR","TVECM"), TVECMmodel="All", sameName=TRUE){
+nameB <- function(mat,commonInter, Bnames, nthresh, npar, model=c("TVAR","TVECM"), TVECMmodel="All", sameName=TRUE){
   model<-match.arg(model)
   addRegLetter<-if(sameName) NULL else  c("L ", if(nthresh==1) NULL else "M ", "H ")
   if(model=="TVAR")
@@ -705,8 +706,8 @@ nameB<-function(mat,commonInter, Bnames, nthresh, npar, model=c("TVAR","TVECM"),
   if(nthresh==1){
     if(commonInter){
       if(model=="TVAR"){
-        colnames(mat)<-c("Intercept",paste(rep(addRegLetter, each=length(sBnames)),rep(sBnames,2)),sep="")
-      } else if(model=="TVECM"){
+        colnames(mat)<-c("Intercept",paste(rep(addRegLetter, each=length(sBnames)),rep(sBnames,2),sep=""))
+      } else if(model=="TVECM") {
         colnames(mat)<-c("ECT-","ECT+", sBnames)
       }
       Blist<-mat
@@ -717,10 +718,10 @@ nameB<-function(mat,commonInter, Bnames, nthresh, npar, model=c("TVAR","TVECM"),
       Blist <- list(Bdown=Bdown, Bup=Bup)
     }
 ##2 thresholds
-  } else{ 
+  } else { 
     if(commonInter){
       if(model=="TVAR")
-        colnames(mat)<-c("Intercept",paste(rep(addRegLetter, each=length(sBnames)),rep(sBnames,3)),sep="")
+        colnames(mat)<-c("Intercept",paste(rep(addRegLetter, each=length(sBnames)),rep(sBnames,3),sep=""))
       else if(model=="TVECM")
         colnames(mat)<-c("ECT-","ECT+", sBnames)
       Blist<-mat}
